.. _module-silx-math:

.. py:module:: silx.math

:mod:`silx.math`:
==================

.. toctree::
   :maxdepth: 1

   fit/index.rst
   histogram.rst
   medianfilter.rst
   combo.rst
   colormap.rst
